# -*- coding: utf-8 -*-
"""DFTimewolf exporters, responsible for exporting processing results."""

import threading

from dftimewolf.lib import utils


class BaseExporter(threading.Thread):
  """Base class for artifact exporters.

  Attributes:
    console_out: DFTimewolfConsoleOutput helper.
    errors: List of errors generated by the collector.
  """

  def __init__(self, verbose):
    super(BaseExporter, self).__init__()
    self.console_out = utils.DFTimewolfConsoleOutput(
        sender=self.__class__.__name__, verbose=verbose)
    self.errors = []

  def run(self):
    """Threads the export() method."""
    self.export()

  def export(self):
    """Export artifacts.

    Returns:
      String containing a reference to the export
    """
    raise NotImplementedError
