# -*- coding: utf-8 -*-
"""DFTimewolf artifact processors, responsible for processing artifacts."""

import threading

from dftimewolf.lib import utils


class BaseArtifactProcessor(threading.Thread):
  """Base class for artifact processors.

  Attributes:
    console_out: DFTimewolfConsoleOutput helper.
    errors: List of errors generated by the processor.
  """

  def __init__(self, verbose):
    super(BaseArtifactProcessor, self).__init__()
    self.console_out = utils.DFTimewolfConsoleOutput(
        sender=self.__class__.__name__, verbose=verbose)
    self.errors = []

  def run(self):
    """Threads the process() method."""
    self.process()

  def process(self):
    """Process artifacts.

    Returns:
      str: path to a file containing results of processing.
    """
    raise NotImplementedError
